@@ -1,86 +1,3 @@
-##' Change a nlmixr fit object to a huxtable
-##'
-##' This is a thin layer that differs from
-##' \code{\link[huxtable]{huxreg}} to make it easier to produce
-##' reasonable huxtables with nlmixr fit objects.
-##'
-##' \itemize{
-##'
-##' \item Drops \code{NA} values from tables, so (\code{NA}) is not
-##' shown for estimates without a standard error.
-##'
-##' \item Filters out any blank rows.
-##'
-##' \item Removes R.squared from the statistics and replaces with the
-##' objective function value.
-##'
-##' \item Adjust broom separators for an easier to read format.
-##'
-##' }
-##'
-##' @inheritParams huxtable::huxreg
-##' @param na_omit How NAs are handled in converting to huxtable
-##'@export
-asHux.nlmixrFitCore  <- function(...,
-                                 error_format    = "({std.error})",
-                                 error_style     = c("stderr", "ci", "statistic", "pvalue"),
-                                 error_pos       = c("below", "same", "right"),
-                                 number_format   = "%.3f",
-                                 align           = ".",
-                                 pad_decimal     = ".",
-                                 ci_level        = NULL,
-                                 tidy_args       = NULL,
-                                 stars           = c("***" = 0.001, "**" = 0.01, "*" = 0.05),
-                                 bold_signif     = NULL,
-                                 borders         = 0.4,
-                                 outer_borders   = 0.8,
-                                 note            = if (is.null(stars)) NULL else "{stars}.",
-                                 statistics      = c("N" = "nobs", "Objective Function" = "OBJF", "logLik", "AIC"),
-                                 coefs           = NULL,
-                                 omit_coefs      = NULL,
-                                 na_omit         = c("all", "any", "none")){
-    RxODE::rxReq("huxtable")
-    .opt  <- options()
-    on.exit(options(.opt));
-    options(broom.mixed.sep1=": ",
-            broom.mixed.sep2=", ")
-    .lst <- as.list(match.call(expand.dots=TRUE))[-1];
-    ## Extract all of the error format columns
-    .glueReg  <- "[{][^}]*[}]"
-    .isComplex  <- FALSE
-    .errCols <- sapply(unlist(stringr::str_extract_all(error_format, .glueReg)),
-                       function(x){
-        .err  <- substr(x, 2, nchar(x) - 1);
-        if (is.name(eval(parse(text=sprintf("quote(%s)", .err))))){
-            return(.err)
-        } else {
-            .isComplex <<- TRUE
-            return(NULL)
-        }
-    })
-    if (!.isComplex){
-        .lst$error_format <- paste0("{ifelse(!sapply(seq_along(",.errCols[1],"), function(x){any(is.na(c(",
-                                    paste(paste0(.errCols,"[x]"),collapse=","),
-                                    ")))}), paste0(\"",
-                                    gsub(rex::rex("{",capture(or(.errCols)),"}"), "\",\\1,\"",error_format),
-                                    "\"),\"\")}");
-    }
-    .lst$statistics  <- statistics
-    .ret <- do.call(huxtable::huxreg,.lst)
-    .w  <- which(sapply(seq_along(.ret$names),function(i){!all(as.character(.ret[i,])=="")}))
-    return(.ret[.w])
-}
-
-##'@export
-as_huxtable.nlmixrFitCore  <- function(x,...){
-    if (missing(x)){
-        .args <- list(...)
-    } else {
-        .args  <- list(x,...);
-    }
-    do.call(asHux.nlmixrFitCore, .args)
-}
-
 .nmMuTable  <- function(x){
     .mu  <- x$nmodel$mu.ref
     if (length(.mu) == 0) return(NULL)
@@ -111,11 +28,13 @@ as_huxtable.nlmixrFitCore  <- function(x,...){
             .ret$covariates[.ret$covariates == "NA"] <- ""
         }
     }
-    .ret  <- huxtable::hux(.ret) %>%
-            huxtable::add_colnames() %>%
-            huxtable::set_bold(row = 1, col = huxtable::everywhere, value = TRUE) %>%
-            huxtable::set_position("center") %>%
-            huxtable::set_all_borders(TRUE)
+    if (requireNamespace("huxtable", quietly = TRUE)){
+      .ret  <- huxtable::hux(.ret) %>%
+        ## huxtable::add_colnames() %>%
+        huxtable::set_bold(row = 1, col = huxtable::everywhere, value = TRUE) %>%
+        huxtable::set_position("center") %>%
+        huxtable::set_all_borders(TRUE)
+    }
     return(.ret)
 }
 
@@ -155,43 +74,56 @@ as_huxtable.nlmixrFitCore  <- function(x,...){
 
 .nmHuxHeader  <- function(x, bound){
     .cor <- x$omega
-    diag(.cor) <- 0;
-    huxtable::tribble_hux(
-                  ~ Description, ~ Value,
-                  "Full nlmixr Version:", .getFullNlmixrVersion(),
-                  "Full RxODE Version:", .getFullNlmixrVersion("RxODE"),
-                  "R Model Function Name ($modelName):",  x$modelName,
-                  "R Fit Object:", bound,
-                  "R Data Name ($dataName):", x$dataName,
-                  "Estimation Method:",.nmEstMethod(x),
-                  "All variables mu-referenced:",dim(x$omega)[1] == length(x$mu.ref),
-                  "Covariance Method ($covMethod):", x$covMethod,
-                  "Modeled Correlations:", !all(.cor == 0),
-                  "CWRES:",ifelse(inherits(x, "nlmixrFitData"), any(names(x)=="CWRES"),FALSE),
-                  "NPDE:",ifelse(inherits(x, "nlmixrFitData"), any(names(x)=="NPDE"),FALSE),
-              ) %>%
-        huxtable::add_colnames() %>%
-            huxtable::set_bold(row = huxtable::everywhere, col = 1, value = TRUE) %>%
-            huxtable::set_bold(row = 1, col = huxtable::everywhere, value = TRUE) %>%
-            huxtable::set_all_borders(TRUE)
+    diag(.cor) <- 0
+    .tab <- tibble::tribble(
+                      ~ Description, ~ Value,
+                      "Full nlmixr Version:", .getFullNlmixrVersion(),
+                      "Full RxODE Version:", .getFullNlmixrVersion("RxODE"),
+                      "R Model Function Name ($modelName):",  x$modelName,
+                      "R Fit Object:", bound,
+                      "R Data Name ($dataName):", x$dataName,
+                      "Estimation Method:",.nmEstMethod(x),
+                      "All variables mu-referenced:",paste(dim(x$omega)[1] == length(x$mu.ref)),
+                      "Covariance Method ($covMethod):", x$covMethod,
+                      "Modeled Correlations:", paste0(!all(.cor == 0)),
+                      "CWRES:",paste0(ifelse(inherits(x, "nlmixrFitData"), any(names(x)=="CWRES"),FALSE)),
+                      "NPDE:",paste0(ifelse(inherits(x, "nlmixrFitData"), any(names(x)=="NPDE"),FALSE)),
+                      )
+    if (requireNamespace("huxtable", quietly = TRUE)){
+      huxtable::as_hux(.tab) %>%
+        ##huxtable::add_colnames() %>%
+        huxtable::set_bold(row = huxtable::everywhere, col = 1, value = TRUE) %>%
+        huxtable::set_bold(row = 1, col = huxtable::everywhere, value = TRUE) %>%
+        huxtable::set_all_borders(TRUE) ->
+        .tab
+    }
+    return(.tab)
 }
 
 
 .nmHuxTime  <- function(x){
-    huxtable::as_hux(x$time) %>%
-        huxtable::add_colnames() %>%
+  .tab <- x$time
+  if (requireNamespace("huxtable", quietly = TRUE)){
+      huxtable::as_hux(.tab) %>%
+        ##huxtable::add_colnames() %>%
         huxtable::set_bold(row = 1, col = huxtable::everywhere, value = TRUE) %>%
-        huxtable::set_all_borders(TRUE)
+        huxtable::set_all_borders(TRUE) -> .tab
+  }
+  return(.tab)
 }
 
 
 .nmHuxObjf  <-function(x){
     .tmp  <- x$objDf;
     .tmp  <- .data.frame(type=row.names(.tmp),.tmp, check.rows=FALSE,check.names=FALSE,stringsAsFactors=FALSE)
-    huxtable::as_hux(.tmp) %>%
-        huxtable::add_colnames() %>%
+    if (requireNamespace("huxtable", quietly = TRUE)){
+      huxtable::as_hux(.tmp) %>%
+        ##huxtable::add_colnames() %>%
         huxtable::set_bold(row = 1, col = huxtable::everywhere, value = TRUE) %>%
-        huxtable::set_all_borders(TRUE)
+        huxtable::set_all_borders(TRUE) ->
+        .tmp
+    }
+    return(.tmp)
 }
 
 .getFullNlmixrVersion  <- function(pkg="nlmixr"){
@@ -407,6 +339,7 @@ nmDocx  <- function(x,
     RxODE::rxReq("officer");
     RxODE::rxReq("flextable");
     RxODE::rxReq("data.table");
+    RxODE::rxReq("huxtable")
     if (!inherits(x, "nlmixrFitCore")){
         stop("This only applies to nlmixr fit objects");
     }
@@ -439,9 +372,9 @@ nmDocx  <- function(x,
     if (!any(headerStyle==.style$style_name)) stop("Need to specify a valid headerStyle");
     if (!any(preformattedStyle==.style$style_name)) stop("Need to specify a valid preformattedStyle");
     if (.bound !=""){
-        .hreg  <- eval(parse(text=sprintf('nlmixr::as_hux("%s"=x)', .bound)));
+        .hreg  <- eval(parse(text=sprintf('huxtable::huxreg("%s"=x)', .bound)));
     } else {
-        .hreg  <- nlmixr::as_hux(x);
+        .hreg  <- huxtable::huxreg(x);
     }
     .doc <- .doc %>%
         officer::body_add_par(sprintf("nlmixr %s (%s)", utils::packageVersion("nlmixr"),
@@ -457,7 +390,7 @@ nmDocx  <- function(x,
         officer::body_add_par("Timing ($time, in seconds)", style=headerStyle) %>%
         flextable::body_add_flextable(flextable::autofit(.asFlx(.nmHuxTime(x))))
     .doc <- .doc %>%
-        officer::body_add_par(sprintf("Parameter Information as_hux(%s)", .bound), style=headerStyle) %>%
+        officer::body_add_par(sprintf("Parameter Information huxreg(%s)", .bound), style=headerStyle) %>%
         flextable::body_add_flextable(flextable::autofit(.asFlx(.hreg)));
     doc <- .doc %>%
         officer::body_add_par("UI Model information ($uif):", style=headerStyle)
@@ -489,22 +422,25 @@ nmDocx  <- function(x,
         .si  <- x$scaleInfo;
         .t1 <- c("est","scaleC")
         .t2  <- c("est","Initial Gradient", "Forward aEps", "Forward rEps", "Central aEps", "Central rEps");
-        .t3  <- c("est","Covariance Gradient","Covariance aEps", "Covariance rEps");
-        .t1  <- huxtable::hux(.si[,.t1]) %>%
-            huxtable::add_colnames() %>%
-            huxtable::set_bold(row = 1, col = huxtable::everywhere, value = TRUE) %>%
-            huxtable::set_position("center") %>%
-            huxtable::set_all_borders(TRUE)
-        .t2  <- huxtable::hux(.si[,.t2]) %>%
-            huxtable::add_colnames() %>%
-            huxtable::set_bold(row = 1, col = huxtable::everywhere, value = TRUE) %>%
-            huxtable::set_position("center") %>%
-            huxtable::set_all_borders(TRUE)
-        .t3  <- huxtable::hux(.si[,.t3]) %>%
-            huxtable::add_colnames() %>%
-            huxtable::set_bold(row = 1, col = huxtable::everywhere, value = TRUE) %>%
-            huxtable::set_position("center") %>%
-            huxtable::set_all_borders(TRUE)
+        .t3  <- c("est","Covariance Gradient","Covariance aEps", "Covariance rEps")
+        .t1 <- .si[,.t1]
+        .t2 <- .si[,.t2]
+        .t3 <- .si[,.t3]
+        .t1  <- huxtable::hux(.t1) %>%
+          ## huxtable::add_colnames() %>%
+          huxtable::set_bold(row = 1, col = huxtable::everywhere, value = TRUE) %>%
+          huxtable::set_position("center") %>%
+          huxtable::set_all_borders(TRUE) 
+        .t2  <- huxtable::hux(.t2) %>%
+          ## huxtable::add_colnames() %>%
+          huxtable::set_bold(row = 1, col = huxtable::everywhere, value = TRUE) %>%
+          huxtable::set_position("center") %>%
+          huxtable::set_all_borders(TRUE)
+        .t3  <- huxtable::hux(.t3) %>%
+          ## huxtable::add_colnames() %>%
+          huxtable::set_bold(row = 1, col = huxtable::everywhere, value = TRUE) %>%
+          huxtable::set_position("center") %>%
+          huxtable::set_all_borders(TRUE)
         .doc <- .doc %>%
             officer::body_add_par("Scaling information (est/scaleC):",style=normalStyle) %>%
             flextable::body_add_flextable(flextable::autofit(.asFlx(.t1))) %>%
@@ -569,6 +505,7 @@ nmLst  <- function(x,
                    lst=NULL){
     RxODE::rxReq("data.table");
     RxODE::rxReq("yaml");
+    RxODE::rxReq("huxtable")
     if (!inherits(x, "nlmixrFitCore")){
         stop("This only applies to nlmixr fit objects");
     }
@@ -585,9 +522,9 @@ nmLst  <- function(x,
         .bound <- .bound[1]
     }
     if (.bound !=""){
-        .hreg  <- eval(parse(text=sprintf('nlmixr::as_hux("%s"=x)', .bound)));
+        .hreg  <- eval(parse(text=sprintf('huxtable::huxreg("%s"=x)', .bound)));
     } else {
-        .hreg  <- nlmixr::as_hux(x);
+        .hreg  <- huxtable::huxreg(x);
     }
     .rule  <- function(msg){
         message("")
@@ -671,13 +608,14 @@ nmSave  <- function(x,...,save=TRUE){
 ## Ugly hacks to make word conversion work without loading flextable, officer, etc
 .huxNS <- NULL;
 .asFlx <- function(x, ...){
-    if (is.null(.huxNS)){
-        ## ugly hack
-        .huxNS <- loadNamespace("huxtable")
-        assignInMyNamespace(".huxNS", .huxNS);
-    }
-    .env <- new.env(parent=.huxNS);
-    .env$x <- x;
-    with(.env, as_flextable.huxtable(x));
+  RxODE::rxReq("huxtable")
+  if (is.null(.huxNS)){
+    ## ugly hack
+    .huxNS <- loadNamespace("huxtable")
+    assignInMyNamespace(".huxNS", .huxNS);
+  }
+  .env <- new.env(parent=.huxNS);
+  .env$x <- x;
+  with(.env, as_flextable.huxtable(x));
 }
 
